summaryrefslogtreecommitdiff
path: root/src/base/ftfntfmt.c
diff options
context:
space:
mode:
authorWerner Lemberg <wl@gnu.org>2015-03-11 07:32:58 +0100
committerWerner Lemberg <wl@gnu.org>2015-03-11 08:54:08 +0100
commitf4d1c11faa116daad655b50828a434babbdaed2a (patch)
tree7e6dfcd6b37d46833a425450d96c1c367d0e81e7 /src/base/ftfntfmt.c
parent3e587796755dbb6be2756b5cd82884feb7da9159 (diff)
downloadfreetype2-f4d1c11faa116daad655b50828a434babbdaed2a.tar.gz
Rename `FT_Get_X11_Font_Format' to `FT_Get_Font_Format'.
* include/ftfntfmt.h, src/base/ftfntfmt.c: Implement it. * docs/CHANGES: Updated.
Diffstat (limited to 'src/base/ftfntfmt.c')
-rw-r--r--src/base/ftfntfmt.c17
1 files changed, 16 insertions, 1 deletions
diff --git a/src/base/ftfntfmt.c b/src/base/ftfntfmt.c
index b9e9395f2..38a5b6054 100644
--- a/src/base/ftfntfmt.c
+++ b/src/base/ftfntfmt.c
@@ -2,7 +2,7 @@
/* */
/* ftfntfmt.c */
/* */
/* FreeType utility file for X11 support (body). */
/* */
/* Copyright 2002-2015 by */
/* David Turner, Robert Wilhelm, and Werner Lemberg. */
@@ -25,6 +25,21 @@
/* documentation is in ftfntfmt.h */
FT_EXPORT_DEF( const char* )
+ FT_Get_Font_Format( FT_Face face )
+ {
+ const char* result = NULL;
+
+
+ if ( face )
+ FT_FACE_FIND_SERVICE( face, result, XF86_NAME );
+
+ return result;
+ }
+
+
+ /* deprecated function name; retained for ABI compatibility */
+
+ FT_EXPORT_DEF( const char* )
FT_Get_X11_Font_Format( FT_Face face )
{
const char* result = NULL;
@@ -2,7 +2,7 @@
/* ftfntfmt.c */
/* */
-/* FreeType utility file for X11 support (body). */
+/* FreeType utility file for font formats (body). */
/* */
/* Copyright 2002-2015 by */